Copulalib
Description: usage page of the Copulalib
Keywords: copula, AMBHAS

# Examples

Suppose we have RADARSAT data in following file structure:

    						        Home
    							 |
    							 |
    							 |
    						       RADARSAT
    							 |
    							 |
    							 |
       ----------------------------------------------------------------------------------------------------------------------
       |                 |             |               |             |             |             |             |            |
       |                 |             |               |             |             |             |             |            |
       |                 |             |               |             |             |             |             |            |
    imagery_VH.tif  imagery_HH.tif imagery_HV.tif  imagery_VV.tif lutSigma.xml  product.xml  lutBeta.xml  lutGamma.xml    schemas

    >>> from radarsatlib.calibrate import calibrate
    >>> sigma = calibrate('/home/RADARSAT/')   # initialize the class
    >>> sigma.speckle_filter('median', 5)      # filter the data using the median filter with a window size of 5
    >>> sigma.save_tiff('/home/tomer/temp/temp.tif')   # save the filtered sigma to a specified path
    >>> sigma.incidence_angle('/home/tomer/temp/ia.tif')  # save the incidence angle image